##  How to Model Initiatives in the Context of Large Transformation Programs (with SAP LeanIX Architecture and Road Map Planning)
The fact sheet initiative (incl. subtypes) is particularly useful and crucial if you use SAP LeanIX to plan and execute larger modernization and transformation projects, in which case you would typically use SAP LeanIX Architecture and Road Map Planning. Check out the [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") use case description to learn how to use the initiative fact sheet type in this context.
**Note**
SAP LeanIX Architecture and Road Map Planning was previously known as BTM module.
For some overarching guidance, let’s say your organization runs 5-10 large programs. Typically these are broken down (via WBS: Work Breakdown Structures) into 2-3 levels. You could model projects or epics on level 2. Or you model projects on level 2 and epics on level 3. It is also possible to have standalone projects.
The following is a modeling example in which an organization uses the SAP LeanIX Architecture and Road Map Planning (which allows to model transformations and create milestones) and wants to provide an overview of its ERP transformation program.
  * ERP Transformation is the broad transformation program. Below that, we have different projects linked as a child that represent the different waves (or phases) of the ERP Transformation program.
  * The program supports the broad objective of reducing costs (which is owned by the Headquarter - organization fact sheet subtype).
  * The projects improve the business capabilities displayed. The business capabilities are supported by the SAP S/4HANA Cloud application and its children.
  * The platform contains those applications (and underlying IT components that are not modeled here), and it supports the objective to reduce IT costs.
  * The applications are used by the two regions Austria and Spain, as well as by the business unit Headquarter (both subtypes of organization)

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ff4397a441014b1f0c5c148730b6b_LowRes.png)
Modeling the initiatives (program and project as children) and linking them to applications will allow you to create a roadmap report for your ERP transformation program that shows the status of the entire program, its projects, and impacted applications. With SAP LeanIX Architecture and Road Map Planning, you can also add and visualize milestones. The documentation on the [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") use cases explains how to get there in detail.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747d54e7a441014b290f77c46f348d3_LowRes.png)
You could now go ahead and also reflect changes based on initiatives in the interface circle map. Below, you find an example of an SAP transformation.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2753038b7a441014849f84075f220860_LowRes.png) ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275118a97a441014833c9b5c5861db2b_LowRes.png)
